@@ -5,6 +5,10 @@ sentry.coreapi
 :copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+# TODO: We should make the API a class, and UDP/HTTP just inherit from it
+#       This will make it so we can more easily control logging with various
+#       metadata (rather than generic log messages which arent useful).
+
 from datetime import datetime
 import base64
 import logging
@@ -20,7 +24,11 @@ from sentry.queue.client import delay
 from sentry.utils import is_float, json
 from sentry.utils.auth import get_signature, parse_auth_header
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('sentry.errors.coreapi')
+
+
+class InvalidTimestamp(ValueError):
+    pass
 
 
 class APIError(Exception):
@@ -177,8 +185,7 @@ def process_data_timestamp(data):
         try:
             data['timestamp'] = datetime.strptime(data['timestamp'], format)
         except:
-            logger.exception('Failed reading timestamp')
-            del data['timestamp']
+            raise InvalidTimestamp('Invalid value for timestamp: %r' % data['timestamp'])
 
     return data
 
